class BaseVideoException(Exception):
    """Base class video processing exceptions"""


class FileNotFoundException(BaseVideoException):
    """Video opening exception"""


class InvalidDataException(BaseVideoException):
    """Video opening exception"""


class UnsupportedVideoFormatException(BaseVideoException):
    """Unsupported video format exception"""


class UnsupportedPixelFormatException(BaseVideoException):
    """Unsupported pixel format exception"""


class PTSNotFound(BaseVideoException):
    """pts in package not found exception"""


class DeviceIsNotAvailableException(BaseVideoException):
    """Decoding device is not available"""


class SeekUnsupportedError(BaseVideoException):
    """Seek is not supported error"""


class UnsupportedUserAngle(BaseVideoException):
    """Rotation angle specified by user is not supported"""


class UnsupportedVideoInfoAngle(BaseVideoException):
    """Rotation angle from video info is not supported"""


class VideoDecodingException(BaseVideoException):
    """
    Error while decoding video
    Attributes:
        frameNumber: decoded frame number
        ts: approximate package ts
    """

    def __init__(self, error: str, frameNumber: int | None = None, ts: float | None = None):
        self.frameNumber = frameNumber
        self.ts = ts
        super().__init__(error)


class VideoDecodingTimeout(VideoDecodingException):
    """Timeout of receiving package"""
